==> chromium-60.0.3112.50.tar.xz: chromium-60.0.3112.50/chrome/browser/resources/settings/languages_page/languages_browser_proxy.js <==
// Copyright 2017 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

/**
 * @fileoverview A helper object used from the languages section
 * to interact with the browser.
 */

cr.define('settings', function() {
  /** @interface */
  function LanguagesBrowserProxy() {}

  LanguagesBrowserProxy.prototype = {
// <if expr="chromeos or is_win">
    /**
     * Sets the prospective UI language to the chosen language. This won't
     * affect the actual UI language until a restart.
     * @param {string} languageCode
     */
    setProspectiveUILanguage: function(languageCode) {},

    /** @return {!Promise<string>} */
    getProspectiveUILanguage: function() {},
// </if>

    /** @return {!LanguageSettingsPrivate} */
    getLanguageSettingsPrivate: function() {},

// <if expr="chromeos">
    /** @return {!InputMethodPrivate} */
    getInputMethodPrivate: function() {},
// </if>
  };

  /**
   * @constructor
   * @implements {settings.LanguagesBrowserProxy}
   */
  function LanguagesBrowserProxyImpl() {}
  // The singleton instance_ is replaced with a test version of this wrapper
  // during testing.
  cr.addSingletonGetter(LanguagesBrowserProxyImpl);

  LanguagesBrowserProxyImpl.prototype = {
// <if expr="chromeos or is_win">
    /** @override */
    setProspectiveUILanguage: function(languageCode) {
      chrome.send('setProspectiveUILanguage', [languageCode]);
    },

    /** @override */
    getProspectiveUILanguage: function() {
      return cr.sendWithPromise('getProspectiveUILanguage');
    },
// </if>

    /** @override */
    getLanguageSettingsPrivate: function() {
      return /** @type {!LanguageSettingsPrivate} */ (
          chrome.languageSettingsPrivate);
    },

// <if expr="chromeos">
    /** @override */
    getInputMethodPrivate: function() {
      return /** @type {!InputMethodPrivate} */ (chrome.inputMethodPrivate);
    },
// </if>
  };

  return {
    LanguagesBrowserProxy: LanguagesBrowserProxy,
    LanguagesBrowserProxyImpl: LanguagesBrowserProxyImpl,
  };
});

==> chromium_81.0.4044.62.orig.tar.xz: chromium-81.0.4044.62/chrome/browser/resources/settings/languages_page/languages_browser_proxy.js <==
// Copyright 2017 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

/**
 * @fileoverview A helper object used from the languages section
 * to interact with the browser.
 */

cr.define('settings', function() {
  /** @interface */
  class LanguagesBrowserProxy {
    // <if expr="chromeos or is_win">
    /**
     * Sets the prospective UI language to the chosen language. This won't
     * affect the actual UI language until a restart.
     * @param {string} languageCode
     */
    setProspectiveUILanguage(languageCode) {}

    /** @return {!Promise<string>} */
    getProspectiveUILanguage() {}

    // </if>

    /** @return {!LanguageSettingsPrivate} */
    getLanguageSettingsPrivate() {}

    // <if expr="chromeos">
    /** @return {!InputMethodPrivate} */
    getInputMethodPrivate() {}
    // </if>
  }

  /**
   * @implements {settings.LanguagesBrowserProxy}
   */
  class LanguagesBrowserProxyImpl {
    // <if expr="chromeos or is_win">
    /** @override */
    setProspectiveUILanguage(languageCode) {
      chrome.send('setProspectiveUILanguage', [languageCode]);
    }

    /** @override */
    getProspectiveUILanguage() {
      return cr.sendWithPromise('getProspectiveUILanguage');
    }

    // </if>

    /** @override */
    getLanguageSettingsPrivate() {
      return /** @type {!LanguageSettingsPrivate} */ (
          chrome.languageSettingsPrivate);
    }

    // <if expr="chromeos">
    /** @override */
    getInputMethodPrivate() {
      return /** @type {!InputMethodPrivate} */ (chrome.inputMethodPrivate);
    }
    // </if>
  }

  // The singleton instance_ is replaced with a test version of this wrapper
  // during testing.
  cr.addSingletonGetter(LanguagesBrowserProxyImpl);

  // #cr_define_end
  return {
    LanguagesBrowserProxy: LanguagesBrowserProxy,
    LanguagesBrowserProxyImpl: LanguagesBrowserProxyImpl,
  };
});
